#include <nRF24L01P.h>

//Target Board's Address
unsigned char TX_Addr[5] ={0x12, 0xDE, 0x78, 0x98, 0xDF};

//Address of this program's board
unsigned char RX_Addr[5] ={0xFF, 0xCD, 0xAB, 0xE7, 0x72};

//Data to be sent
unsigned char DATA[3][11] = {"QWERTYUIOP",
                             "ASDFGHJKL0",
                             "MNBVCXZ346"};
                             
unsigned char i;

//Variable for holding Data Pipe number and Data Width
//of received data
unsigned char DataPipe, DataWidth;

//For holding received data
unsigned char ReceivedData[10];

//Assignment nRF24L01P Pin to Arduino Mega
//Prototype nRF24L01P(CE_Pin, CSN_Pin, CLK_Pin, MOSI_Pin, MISO);
//Following Line means
//Pin 7 of Arduino Board is connected to CE Pin of nRF24L01+ Moudle
//Pin 6 of Arduino Board is connected to CSN Pin of nRF24L01+ Moudle
//Pin 5 of Arduino Board is connected to CLK Pin of nRF24L01+ Moudle
//Pin 4 of Arduino Board is connected to MOSI Pin of nRF24L01+ Moudle
//Pin 3 of Arduino Board is connected to MISO Pin of nRF24L01+ Moudle
nRF24L01P RF(7, 6, 5, 4, 3);

void setup()
{
  //Set Baudrate 115200
  Serial.begin(115200);
  
  //Use the on board LED
  pinMode(13, OUTPUT);
  
  //Initialize the nRF24L01+ RF module
  RF.DefaultShockBurstSetting();
  
  //Set Address Width is 5 Bytes
  RF.setAddressWidth(5);
  
  //Set Target Board's Address with 5 Bytes
  RF.setTXAddress(RX_Addr, 5);
  
  //Data Pipe 0's RX Address MUST be same as 
  //target board's address
  //This is required for auto acknowledgement function
  RF.setRXAddress(RX_Addr, 5, 0);
  
  //Use Data Pipe 1 as main receiver channel
  //of this board
  RF.setRXAddress(TX_Addr, 5, 1);
  
  //set Payload Width is 10 Bytes in Data Pipe 0
  //Payload means number of bytes of data 
  //which to be received
  //*******************************************
  //* Note:                                   *
  //*    Please always keep in mind that the  *
  //* receiver data pipe payload length MUST  *
  //* be the length of transmitted data.      *
  //* Othwerise, receiver will not receive    *
  //* any data.                               *
  //*******************************************
  RF.setRXPayloadWidth(0, 10); 
  
  //set Payload Width is 10 Bytes in Data Pipe 1
  RF.setRXPayloadWidth(1, 10); 
}//end setup

void loop()
{
    //Data Received
    if(RF.Available())
    {
      //Flash on board LED
      digitalWrite(13, HIGH);
      delay(50);
      digitalWrite(13, LOW);
      delay(50);
      
      //To obtain the received data from nRF24L01+ RF module
      //DataPipe for holding that the data is came from which data pipe
      //DataWidth for holding the number of bytes of received data
      //If Data Pipe and Data Width are not been cared, 
      //RF.getData(ReceivedData) can be used.
      RF.getData(ReceivedData, &DataPipe, &DataWidth);
      
      //Send to PC
      Serial.print("Payload / Received Data: ");
      for(i=0; i<DataWidth; i++)
        Serial.print(ReceivedData[i]);
      Serial.print("\n");
      
      Serial.print("From Data Pipe: ");
      Serial.println(DataPipe, DEC);
      
      Serial.print("Data Width in Byte(s): ");
      Serial.println(DataWidth, DEC);
      
      Serial.print("\n");
  }//end if
}//end loop
