#include <nRF24L01P.h>

/**************************************************************
* Note: For the Dynamic Payload Function, the maximum Paylaod *
*       is 31 bytes.                                          *
**************************************************************/

//Receiver Address for 6 Data Pipe of this board
unsigned char RX_Addr[6][5] ={{0xAB, 0xDE, 0x78, 0x98, 0xDF},
                              {0xFF, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x12, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x13, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x14, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x15, 0xCD, 0xAB, 0xE7, 0x72}};
                             
//Variable for holding Data Pipe number and Data Width
//of received data
unsigned char DataPipe, DataWidth;

//For holding received data
unsigned char ReceivedData[34];

unsigned char i;

//Assignment nRF24L01P Pin to Arduino Mega
//Prototype nRF24L01P(CE_Pin, CSN_Pin, CLK_Pin, MOSI_Pin, MISO);
//Following Line means
//Pin 7 of Arduino Board is connected to CE Pin of nRF24L01+ Moudle
//Pin 6 of Arduino Board is connected to CSN Pin of nRF24L01+ Moudle
//Pin 5 of Arduino Board is connected to CLK Pin of nRF24L01+ Moudle
//Pin 4 of Arduino Board is connected to MOSI Pin of nRF24L01+ Moudle
//Pin 3 of Arduino Board is connected to MISO Pin of nRF24L01+ Moudle
nRF24L01P RF(7, 6, 5, 4, 3);

void setup()
{
  //Set Baudrate 115200
  Serial.begin(115200);
  
  //Use the on board LED
  pinMode(13, OUTPUT);
  
  //Initialize the nRF24L01+ RF module
  //operating in Dynamic Payload Mode
  RF.DefaultDynamicPayloadSetting();
  
  //Set Address Width is 5 Bytes
  RF.setAddressWidth(5);

  RF.setRXPayloadWidth(0, 10);
  
  //Set Data Pipe 0 Address
  RF.setRXAddress(RX_Addr[0], 5, 0);
  
  //Set Data Pipe 1 Address
  RF.setRXAddress(RX_Addr[1], 5, 1);
  
  //Set Data Pipe 2 Address
  RF.setRXAddress(RX_Addr[2], 5, 2);
  
  //Set Data Pipe 3 Address
  RF.setRXAddress(RX_Addr[3], 5, 3);
  
  //Set Data Pipe 4 Address
  RF.setRXAddress(RX_Addr[4], 5, 4);
  
  //Set Data Pipe 5 Address
  RF.setRXAddress(RX_Addr[5], 5, 5);
  
  RF.DataPipeEnableDynamicPldLen(0);
  
  //Set Data Pipe 2 to 5 work with
  //Dynamic Payload Function.
  //Data Pipe 0 and 1 are set in
  //DefaultDynamicPayloadSetting
  //function already.
  RF.DataPipeEnableDynamicPldLen(2);
  RF.DataPipeEnableDynamicPldLen(3);
  RF.DataPipeEnableDynamicPldLen(4);
  RF.DataPipeEnableDynamicPldLen(5);

  RF.setMode(RX);
}//end setup

void loop()
{
  //Data Received
  if(RF.Available())
  {
    //Flash on board LED
    digitalWrite(13, HIGH);
    delay(50);
    digitalWrite(13, LOW);
    delay(50);
      
    //To obtain the received data from nRF24L01+ RF module
    //DataPipe for holding that the data is came from which data pipe
    //DataWidth for holding the number of bytes of received data
    //If Data Pipe and Data Width are not been cared, 
    //RF.getData(ReceivedData) can be used.
    RF.getData(ReceivedData, &DataPipe, &DataWidth);
  
    //Send to PC
    Serial.print("Payload / Received Data: ");
    for(i=0; i<DataWidth; i++)
      Serial.print(ReceivedData[i]);
    Serial.print("\n");
    
    Serial.print("From Data Pipe: ");
    Serial.println(DataPipe, DEC);
    
    Serial.print("Data Width in Byte(s): ");
    Serial.println(DataWidth, DEC);
    
    Serial.print("\n");
  }//end if
}//end loop
