#include <nRF24L01P.h>

/**************************************************************
* Note: For the Dynamic Payload Function, the maximum Paylaod *
*       is 31 bytes.                                          *
**************************************************************/

//Target Board's Address
unsigned char TX_Addr[6][5] ={{0xAB, 0xDE, 0x78, 0x98, 0xDF},
                              {0xFF, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x12, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x13, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x14, 0xCD, 0xAB, 0xE7, 0x72},
                              {0x15, 0xCD, 0xAB, 0xE7, 0x72}};

//Data to be sent
unsigned char DATA[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ12345";
                             
unsigned char i, j;

//Assignment nRF24L01P Pin to Arduino Mega
//Prototype nRF24L01P(CE_Pin, CSN_Pin, CLK_Pin, MOSI_Pin, MISO);
//Following Line means
//Pin 7 of Arduino Board is connected to CE Pin of nRF24L01+ Moudle
//Pin 6 of Arduino Board is connected to CSN Pin of nRF24L01+ Moudle
//Pin 5 of Arduino Board is connected to CLK Pin of nRF24L01+ Moudle
//Pin 4 of Arduino Board is connected to MOSI Pin of nRF24L01+ Moudle
//Pin 3 of Arduino Board is connected to MISO Pin of nRF24L01+ Moudle
nRF24L01P RF(7, 6, 5, 4, 3);

void setup()
{
  //Use the on board LED
  pinMode(13, OUTPUT);
  
  //Initialize the nRF24L01+ RF module
  //RF.DefaultShockBurstSetting();
  RF.DefaultDynamicPayloadSetting();

  //Set Address Width is 5 Bytes
  RF.setAddressWidth(5);
  
}//end setup


void loop()
{
  for(j=0; j<6; j++)
  {
    //Set Target Board's Address  with 5 Bytes
    RF.setTXAddress(TX_Addr[j], 5);
  
    //Data Pipe 0's RX Address MUST be same as 
    //target board's address
    //This is required for auto acknowledgement function
    RF.setRXAddress(TX_Addr[j], 5, 0);

    //Send data to target board
    for(i=1; i<=31; i++)
    {
      //Send out data
       RF.Transmit(DATA, i);
				
      //The data cannot be sent 
      //to target board. The on
      //board LED will be flashed.
      if(!RF.isTransmitted())
      {
        digitalWrite(13, HIGH);
        delay(200);
        digitalWrite(13, LOW);
        delay(200);
      }
		 
      //Delay 500ms   
      delay(500);
    }//end inner for loop
  }//end outer for loop
}//end loop
